/// <reference types="node" />
/**
 * @class
 * @implements {RootsReader}
 * @implements {BlockReader}
 */
export default class NodeCarReader extends CarReader implements RootsReader, BlockReader {
    /**
     * Reads a block directly from a file descriptor for an open CAR file. This
     * function is **only available in Node.js** and not a browser environment.
     *
     * This function can be used in connection with {@link CarIndexer} which emits
     * the `BlockIndex` objects that are required by this function.
     *
     * The user is responsible for opening and closing the file used in this call.
     *
     * @async
     * @static
     * @memberof CarReader
     * @param {fs.promises.FileHandle | number} fd A file descriptor from the
     * Node.js `fs` module. Either an integer, from `fs.open()` or a `FileHandle`
     * from `fs.promises.open()`.
     * @param {BlockIndex} blockIndex An index pointing to the location of the
     * Block required. This `BlockIndex` should take the form:
     * `{cid:CID, blockLength:number, blockOffset:number}`.
     * @returns {Promise<Block>} A `{ cid:CID, bytes:Uint8Array }` pair.
     */
    static readRaw(fd: fs.promises.FileHandle | number, blockIndex: BlockIndex): Promise<Block>;
    constructor(version: number, roots: import("multiformats").CID[], blocks: import("../api.js").Block[]);
}
export const __browser: false;
export type Block = {
    cid: import("multiformats").CID;
    bytes: Uint8Array;
};
export type BlockIndex = import("../api.js").BlockHeader & {
    offset: number;
    blockOffset: number;
};
export type RootsReader = import("../api.js").RootsReader;
export type BlockReader = import("../api.js").BlockReader;
import CarReader from "./reader-browser.js";
import fs from "fs";
//# sourceMappingURL=reader.d.ts.map